@@ -1,14 +1,14 @@
 set.seed(1)
-n <- 800
+n <- 300
 p <- 2
 theta_1 <- matrix(c(-0.3, 0.6, -0.5, 0.4, 0.2, 0.2, 0.2, -0.2), nrow = p)
 theta_2 <- matrix(c(0.3, -0.4, 0.1, -0.5, -0.5, -0.2, -0.5, 0.2), nrow = p)
 x <- matrix(0, n + 2, p)
-for (i in 1:500) {
+for (i in 1:200) {
   x[i + 2, ] <- theta_1 %*% c(x[i + 1, ], x[i, ]) + rnorm(p, 0, 1)
 }
-for (i in 501:n) {
+for (i in 201:n) {
   x[i + 2, ] <- theta_2 %*% c(x[i + 1, ], x[i, ]) + rnorm(p, 0, 1)
 }
-result <- fastcpd.var(x, 2, cost_adjustment = NULL)
+result <- fastcpd.var(x, 2, pruning = FALSE)
 summary(result)
