@@ -4,7 +4,7 @@ testthat::test_that(
     testthat::expect_equal(result@cp_set, 10006)
 
     # Something is seriously wrong if the running time is greater than
-    # 10 seconds.
-    testthat::expect_true(result_time[3] < 10)
+    # 30 seconds.
+    testthat::expect_lt(result_time[3], 30)
   }
 )
